==> jc-1.4.0.tar.gz: javax/print/attribute/HashPrintRequestAttributeSet.h <==
// public class javax.print.attribute.HashPrintRequestAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 760958c48bd25c06 javax_print_attribute_HashPrintRequestAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashPrintRequestAttributeSet_H_
#define _JC_javax_print_attribute_HashPrintRequestAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_PrintRequestAttribute$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$refs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object	_jc_javax_print_attribute_HashPrintRequestAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct	_jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24PrintRequestAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *);
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$be1e5464a26946dc(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$0ca123b9de7369cc(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$ef2b6059dd1448d0(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *, struct _jc_object_array *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashPrintRequestAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods	javax_print_attribute_HashPrintRequestAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$refs {
    _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs	javax_print_attribute_HashPrintRequestAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs	javax_print_attribute_HashPrintRequestAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object {
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype _jc_javax_print_attribute_HashPrintRequestAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashPrintRequestAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashPrintRequestAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashPrintRequestAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/HashPrintRequestAttributeSet.h <==
// public class javax.print.attribute.HashPrintRequestAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 760958c48bd25c06 javax_print_attribute_HashPrintRequestAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashPrintRequestAttributeSet_H_
#define _JC_javax_print_attribute_HashPrintRequestAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_PrintRequestAttribute$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$refs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs	_jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object	_jc_javax_print_attribute_HashPrintRequestAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct	_jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24PrintRequestAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashPrintRequestAttributeSet$fields_struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$be1e5464a26946dc(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$0ca123b9de7369cc(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintRequestAttributeSet$method$_init$ef2b6059dd1448d0(_jc_env *, struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashPrintRequestAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vmethods	javax_print_attribute_HashPrintRequestAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$refs {
    _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_refs	javax_print_attribute_HashPrintRequestAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashPrintRequestAttributeSet$sub_nonrefs	javax_print_attribute_HashPrintRequestAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashPrintRequestAttributeSet$object {
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashPrintRequestAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashPrintRequestAttributeSet$vtype _jc_javax_print_attribute_HashPrintRequestAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashPrintRequestAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashPrintRequestAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashPrintRequestAttributeSet_H_ */
